@@ -7,7 +7,7 @@
 #include "BlockData/cblkGene.h"
       subroutine cgetXsIni
 #include "Zevhnp.h"
-c  #include "Zmanagerp.h"
+!  #include "Zmanagerp.h"
       SxAbySxpOpt = 0
       end subroutine cgetXsIni
 !          This is somewhat totology; dpm cannot
@@ -20,8 +20,8 @@ c  #include "Zmanagerp.h"
 #include  "Ztrack.h"
 #include  "Ztrackv.h"
 !        
-      record /ptcl/ pj    ! input projectile
-      record /ptcl/ tg    ! input target
+      type(ptcl):: pj    ! input projectile
+      type(ptcl):: tg    ! input target
       real(8),intent(out):: xs ! in mb
 
       real(8):: mfp
