@@ -11,8 +11,8 @@
       use modsibyllXs
       implicit none
 #include "Zptcl.h"
-      record /ptcl/ pj    ! input projectile
-      record /ptcl/ tg    ! input target
+      type(ptcl):: pj    ! input projectile
+      type(ptcl):: tg    ! input target
       real(8),intent(out):: xs ! in mb
       call csibyllXs(pj, tg, xs)
       end      subroutine cgetXsInterface
