@@ -312,12 +312,12 @@ c                   write(*, '(7g14.4, 3i3, i6, 2g16.6, 2g14.3, i8)' )
 c                   write(*, '(2g14.4, 3i3, i6)')
 c     *               sngl(x), pt, a(j).code, a(j).subcode, a(j).charge,
 c     *               ntp
-                   write(*, '(7g14.4, 3i3, i6, 2g16.6, 2g14.4, i8)' )
-     *               sngl(x), sngl(xcms), pz, pzcms, sngl(y), 
-     *               sngl(eta),  pt, 
-     *               a(j).code, a(j).subcode, a(j).charge,
-     *               ntp, teta, tetacms,
-     *               ke, kecms, k
+ccc                   write(*, '(7g14.4, 3i3, i6, 2g16.6, 2g14.4, i8)' )
+ccc     *               sngl(x), sngl(xcms), pz, pzcms, sngl(y), 
+ccc     *               sngl(eta),  pt, 
+ccc     *               a(j).code, a(j).subcode, a(j).charge,
+ccc     *               ntp, teta, tetacms,
+ccc     *               ke, kecms, k
                 else
                    call cvisualizeTrack(a(j), 0, ext*0.35)
                 endif
