@@ -1,40 +1,52 @@
-c  ***********************************************************
-c  *     open a sequential disk file.
-c  *     This is intended to open a file that exists already
-c  *     for formatted mode. If it doen not
-c  *     exist or cannot be opened, return cond =1 
-c  ***********************************************************
+!  ***********************************************************
+!  *     open a sequential disk file.
+!  *     This is intended to open a file that exists already
+!  *     for formatted mode. If it doen not
+!  *     exist or cannot be opened, return cond =1 
+!  ***********************************************************
          subroutine copenf(io, fnin, icon)
-c           io: integer. input.  Fortran logical device number
-c           fnin: character(*). input. Disk file name to be openend.
-c                     All %, #, #1, #2, @  $  treated as follows:
-c                     $(XXX) type.  XXX is regarded as enevrionmental
-c                       variable and replaced actual valu
-c                     $XXX/ or $XXX   type.  same as above
-c
-c                     @ is replaced by the hostname if PercentEnv is ' '
-c                          If hostname contianes domainname, only hostname
-c                          is extracted.   
-c                     #1 is replaced by the initial Seed of the random number
-c                        (1st of 2 32-bit integers)
-c                     #2 is //
-c                        (2nd of 2 32 bit integers)
-c                     If # is not followed by 1 or 2, it
-c                     is replaced by unix process number if SharpEnv is ' '.
-c
-c                     % is replaoced  by YYMMDDHHMMSS if PercentEnv is ' '
-c                  
-c                     In all cases above, if the corresponding variable
-c                     (AtEnv etc is non blank (say, 'XYZ'),
-c                     the envrionmental variable XYZ is assumed to exist
-c                     and its value is used instead of hostname etc.
-c
-c         icon: integer. output. 0--> ok
-c                                1--> cannot be opened.
+!           io: integer. input.  Fortran logical device number
+!          fnin: character(*). input. Disk file name to be openend.
+!               top blanks, if any, are removed.
+!               This is needed for Gfortran(see note below)
+!                     All %, #, #1, #2, @  $  treated as follows:
+!                     $(XXX) type.  XXX is regarded as enevrionmental
+!                       variable and replaced actual valu
+!                     $XXX/ or $XXX   type.  same as above
+!
+!                     @ is replaced by the hostname if AtEnv is ' '
+!                          If hostname contianes domainname, only hostname
+!                          is extracted.   
+!                     #1 is replaced by the initial Seed of the random number
+!                        (1st of 2 32-bit integers)
+!                     #2 is //
+!                        (2nd of 2 32 bit integers)
+!                     If # is not followed by 1 or 2, it
+!                     is replaced by unix process number if SharpEnv is ' '.
+!
+!                     % is replaoced  by YYMMDDHHMMSS if PercentEnv is ' '
+!                  
+!                     In all cases above, if the corresponding variable
+!                     (AtEnv etc is non blank (say, 'XYZ'),
+!                     the envrionmental variable XYZ is assumed to exist
+!                     and its value is used instead of hostname etc.
+!     NOTE:
+!    Suppose a progam
+!     integer:: i
+!     character(10):: fname
+!     read(*, '(i2, a)')  i, fname
+!     call copenf(11, fname, icon)
+!     and this executable is a.out:     echo 10 "input" | ./a.out
+!     will get fname as " input". and the open statement
+!     result in error because file " input" is non existent. (Gfortran on mac).
+!     (don't know  Linux Gfortran).   If echo "input" | ...  top blank is not
+!     added.         
+!         icon: integer. output. 0--> ok
+!                                1--> cannot be opened.
          implicit none
 #include "Zreadonly.h"
 
-         character*(*) fnin
+         character(*),intent(in):: fnin
          logical opn, ex
          integer io, ios, icon, klena, fornamelist
          character*300 msg
@@ -42,13 +54,13 @@ c                                1--> cannot be opened.
 
          fornamelist = 0
          goto 10
-c        ***************
+!        ***************
          entry  copenNLf(io, fnin, icon)
-c        ***************
+!        ***************
          fornamelist = 1
  10      continue
          call cgetfname(fnin, fn)
-c                  see if already opened.
+!                  see if already opened.
              inquire(file=fn(1:klena(fn)), opened=opn, exist=ex)
              if(opn) then
                 icon = 0
@@ -62,8 +74,8 @@ c                  see if already opened.
 #endif
 
 #ifdef ACTION_READ
-c                     for non-writable file action ='read'
-c                      is needed.
+!                     for non-writable file action ='read'
+!                      is needed.
                 if(fornamelist .eq. SPECIAL) then
                    open(io, file=fn(1:klena(fn)), 
      *            iostat=ios, access='sequential',
@@ -100,18 +112,18 @@ c                      is needed.
                  icon = 1
              endif    
          end
-c  ***********************************************************
-c  *     open a sequential disk file.
-c  *     This is intended to open a file 
-c  *     for formatted i/o mode. If it
-c  *     cannot be opened, return cond =1 
-c  ***********************************************************
+!  ***********************************************************
+!  *     open a sequential disk file.
+!  *     This is intended to open a file 
+!  *     for formatted i/o mode. If it
+!  *     cannot be opened, return cond =1 
+!  ***********************************************************
          subroutine copenfw(io, fnin, icon)
-c      
-c           io: integer. input.  Fortran logical device number
-c           fnin: character(*). input. Disk file name to be openend.
-c         icon: integer. output. 0--> ok
-c                                1--> cannot be opened.
+!      
+!           io: integer. input.  Fortran logical device number
+!           fnin: character(*). input. Disk file name to be openend.
+!         icon: integer. output. 0--> ok
+!                                1--> cannot be opened.
          implicit none
 #include "Zreadonly.h"
 
@@ -124,14 +136,14 @@ c                                1--> cannot be opened.
          fornamelist = 0
          goto 10
 
-c        *******************
+!        *******************
          entry copenNLfw(io, fnin, icon)
-c        *******************
+!        *******************
          fornamelist = 1
  10      continue
 
          call cgetfname(fnin, fn)
-c                  see if already opened.
+!                  see if already opened.
              inquire(file=fn(1:klena(fn)), opened=opn, exist=ex)
              if(opn) then
                 icon = 0
@@ -177,21 +189,21 @@ c                  see if already opened.
       implicit none
       integer iodev
 
-c          skip to the end of previous write
+!          skip to the end of previous write
        do while(.true.)
           read(iodev, *, end=100)
        enddo
  100   continue
        end
-c  ***********************************************************
-c  *     open a sequential disk file.( upgraded verson of
-c  *     copenfw:
-c  *     This is intended to open a file
-c  *     for formatted or unformatted i/o mode.
-c  ***********************************************************
+!  ***********************************************************
+!  *     open a sequential disk file.( upgraded verson of
+!  *     copenfw:
+!  *     This is intended to open a file
+!  *     for formatted or unformatted i/o mode.
+!  ***********************************************************
          subroutine copenfw2(io, fnin,  form, icon)
          implicit none
-c
+!
          integer  io ! input.  Fortran logical device number
          character*(*)  fnin !  input. Disk file name to be openend.
          integer  form !  input. if 1--> formatted file
@@ -214,7 +226,7 @@ c
      *      'form input to chookopenfw is  invalid',0)
          endif
          call cgetfname(fnin, fn)  !  replace @ # etc to hostname etc
-c                  see if already opened.
+!                  see if already opened.
          inquire(file=fn(1:klena(fn)), opened=opn, exist=ex)
          if(opn) then
             icon = 2
@@ -241,14 +253,14 @@ c                  see if already opened.
             endif
          endif
          end
-c           upgraded version of cskiptoEOF
+!           upgraded version of cskiptoEOF
       subroutine cskiptoEOF2(iodev, form)
       implicit none
       integer iodev  ! input  dev. no
       integer form   ! input  1--> ascii file
                      !        2--> binary file
 
-c          skip to the end of previous write
+!          skip to the end of previous write
        do while(.true.)
           if(form .eq. 1) then
              read(iodev, *, end=100)
@@ -269,9 +281,12 @@ c          skip to the end of previous write
 
 
       integer j
-
       fn = ' '
-      fn = fnin
+      if( fnin(1:1) == "~" ) then
+         fn = "$HOME/"//fnin(2:)
+      else
+         fn = fnin
+      endif
       j = index( fn, '$')
       do while ( j > 0 ) 
          call creplst( fn, j, '$')
@@ -305,7 +320,15 @@ c          skip to the end of previous write
       do while ( j .gt. 0 )
          call creplst( fn, j, '@')
          j = index (fn, '@') 
-      enddo   
+      enddo
+
+      do 
+         if(fn(1:1) /= " ") then
+            exit
+         endif
+         fn = fn(2:)            
+      enddo
+      
       end
       subroutine creplst( fn, j, ch )
       implicit none
@@ -328,7 +351,7 @@ c          skip to the end of previous write
       jj = 1
       if( ch  == '$' ) then
          if( fn(j+1:j+1) == '(' ) then
-c                 $(USER) style
+!                 $(USER) style
             jp =index( fn(j+1:), ')') 
             if( jp > 0 ) then
                jj = jp + j -1 
@@ -337,7 +360,7 @@ c                 $(USER) style
                if(leng == 0 ) then
                   write(0,*) ' envrironmetal variable =', envname
                   write(0,*) ' not found for fn=',trim(fn)
-                  stop
+                  goto 100
                endif
                jj = jj + 1
                jj = jj-j+1
@@ -347,22 +370,22 @@ c                 $(USER) style
                stop
             endif
          else
-c            $USER/  type or $USER only
+!            $USER/  type or $USER only
             jp =index( fn(j+1:), '/') 
             if( jp > 0 ) then
                jj = jp + j-1 
-c             1       jj           
-c             /tmp/$USER/ 
+!             1       jj           
+!             /tmp/$USER/ 
                envname = fn(j+1:jj)
             else
                envname = trim(fn(j+1:))
-c                  USER
+!                  USER
                jj = len(trim(fn(j+1:)))+j
             endif
             leng = kgetenv2(envname, replst)
             if(leng == 0 ) then
                write(0,*) ' Env. =', envname, ' not exist'
-               stop
+               goto 100
             endif
             jj = jj - j + 1
          endif
@@ -375,7 +398,8 @@ c                  USER
                call cerrorMsg(
      *         'Environmental variable specified by AtEnv=', 1)
                call cerrorMsg(AtEnv, 1)
-               call cerrorMsg(' Not exist ', 0)
+               call cerrorMsg(' Not exist ', 1)
+               goto 100
             endif
          else   
             call cgetHost(leng, replst)
@@ -404,7 +428,8 @@ c                  USER
                call cerrorMsg(
      *         'Environmental variable specified by SharpEnv=', 1)
                call cerrorMsg(SharpEnv, 1)
-               call cerrorMsg(' Not exist ', 0)
+               call cerrorMsg(' Not exist ', 1)
+               goto 100
             endif
          else
             replst = ' '
@@ -420,7 +445,8 @@ c                  USER
                call cerrorMsg(
      *         'Environmental variable specified by PercentEnv=', 1)
                call cerrorMsg(PercentEnv, 1)
-               call cerrorMsg(' Not exist ', 0)
+               call cerrorMsg(' Not exist ', 1)
+               goto 100
             endif
          else
             replst = ' '
@@ -436,9 +462,12 @@ c                  USER
      *        fn(1:j-1)//replst(1:leng)//fn(jj+j:)
          fn = fntemp
       endif
-
+      return
+ 100  continue
+      write(0,*) ' input fn=',fn
+      stop
       end
-c      **************
+!      **************
       subroutine cgetHost(leng, hostn)
       integer  leng       ! output
       character*(*) hostn ! output
