@@ -6,34 +6,34 @@
 #include  "Zcode.h"
        integer  atms, z
        integer np       ! output.
-       record /ptcl/ a  ! output. 
-c
-c         atms: input.  atomic mass
-c            z: input.   charge of the capturer
-c         give neu(mu) which comes from captured
-c         negative muon.
-c        er:   recoil nutron average kinetic energy.
+       type(ptcl):: a  ! output. 
+!
+!         atms: input.  atomic mass
+!            z: input.   charge of the capturer
+!         give neu(mu) which comes from captured
+!         negative muon.
+!        er:   recoil nutron average kinetic energy.
        real*8 er, xm, e, cs, sn, u, cost, x, sint
 
          parameter (er=15.e-3, xm=er/masmu/(masmu-er) )
-c
+!
          if(atms .eq. 1) then
              e=masmu
          else
-c                sample x from x*exp(-x)dx with mean xm.
+!                sample x from x*exp(-x)dx with mean xm.
              call ksgmrm(1.00d0, xm, x)
-c               energy of neutrino; peaked at around 100 MeV
+!               energy of neutrino; peaked at around 100 MeV
              e= 1./(1./masmu + x )
          endif
-c          make neutrino of muon type
+!          make neutrino of muon type
          call cmkptc(kneumu, regptcl, 0, a)
          call kcossn(cs, sn)
          call rndc(u)
          cost=2*u-1.
          sint = sqrt(1.d0 - cost**2)
-         a.fm.p(1) = cs*sint*e
-         a.fm.p(2) = sn*sint*e
-         a.fm.p(3) = cost*e
-         a.fm.p(4) = e
+         a%fm%p(1) = cs*sint*e
+         a%fm%p(2) = sn*sint*e
+         a%fm%p(3) = cost*e
+         a%fm%p(4) = e
          np=1
        end
