@@ -3,8 +3,8 @@
 #include  "Zmagfield.h"
 #include  "Zearth.h"
       real*8 yearin, lat, long, height
-      record /coord/ llh
-      record /magfield/ h
+      type(coord):: llh
+      type(magfield):: h
       integer icon
                                   
       character*100 filepath
@@ -30,10 +30,10 @@
                write(0,*) ' icon = ', icon, 'from cgeoma'
                stop
             endif
-c            write(*,*)  ' icon=',icon, ' h.x,y,z=',h.x, h.y, h.z
-c            write(*,*) ' |B|=',sqrt(h.x**2 + h.y**2 + h.z**2)
+!            write(*,*)  ' icon=',icon, ' h.x,y,z=',h.x, h.y, h.z
+!            write(*,*) ' |B|=',sqrt(h.x**2 + h.y**2 + h.z**2)
             write(*,'(1p, 3g13.4)') 
-     *         long, lat, sqrt(h.x**2 + h.y**2 + h.z**2)
+     *         long, lat, sqrt(h%x**2 + h%y**2 + h%z**2)
          enddo
          write(*,*) " "
       enddo
