@@ -1,13 +1,13 @@
-c     at execution, give namelist data by redirection. e.g.,
-c      mkInc < ../../Data/Namelist/parameters
-c
+!     at execution, give namelist data by redirection. e.g.,
+!      mkInc < ../../Data/Namelist/parameters
+!
       program testMkInc
       implicit none
 #include "Ztrack.h"
 
-      record /track/ anIncident
+      type(track)::anIncident
 
-c
+!
       call creadParam(5)
       call cinitObs
       call cmkIncident(anIncident)
