@@ -1,5 +1,5 @@
 #if FNODATDEF > 0
       integer bufsize
       parameter (bufsize=BUFSIZE)
-      record /buffer/ buf(bufsize)
+      type(buffer):: buf(bufsize)
 #endif
