@@ -5,7 +5,7 @@
 #if FNODATDEF > 0
       integer bufc, fnodat
       parameter (fnodat = FNODATDEF)
-      structure /buffer/
+      type buffer
          integer*2 ldep
          integer*2 code
          integer*2 subcode
@@ -19,5 +19,5 @@
          real wx
          real wy
          real wz
-      end structure
+      end type buffer
 #endif
