@@ -862,6 +862,7 @@
 #include  "Zmanagerp.h"
 #include  "Zmanager.h"
 #include  "Ztrackp.h"
+      integer,save:: nthev=0
       include  "Zprivate.h"
 ! general process information; only for dpmjet3
       INTEGER IPROCE,IDNODF,IDIFR1,IDIFR2,IDDPOM,IPRON
@@ -892,6 +893,8 @@
       type (ptcl):: pcms, pl
       type (fmom):: gc
 !/////////////
+      nthev=nthev+1
+      
       npzm = 0
       npzp = 0
       Nchpzm = 0
@@ -915,17 +918,17 @@
       enddo
       Ncht = Nchpzm + Nchpzp
       call getDiffCode(nw, diffcode)
-      write(*,'("h ",i3, 6i6)' ) 
-     *   diffcode(1), ntp, npzm, npzp, Ncht, Nchpzm, Nchpzp
+      write(*,'("h ",i3, 7i6)' ) 
+     * diffcode(1), ntp, npzm, npzp, Ncht, Nchpzm, Nchpzp, nthev
 
       do j = 1, ntp
          i = indx(j)
          pt = sqrt( a(i)%fm%p(1)**2 + a(i)%fm%p(2)**2)
-!         p= sqrt( pt**2  +    a(i).fm.p(3)**2 )
+         p= sqrt( pt**2  +    a(i).fm.p(3)**2 )
 !
 !         wx = a(i).fm.p(1)/p               
 !         wy = a(i).fm.p(2)/p               
-!         wz = a(i).fm.p(3)/p               
+         wz = a(i).fm.p(3)/p               
 !         if(xyz .eq. 0) then
 !            write(*,'(3i3,g14.5,3f17.13, i5)')
 !     *        a(i).code, a(i).subcode, a(i).charge,
@@ -949,10 +952,15 @@
 !     *   a(i).code,  a(i).charge,  pt,  eta, pl.fm.p(4)-pl.mass,
 !     *     a(i).fm.p(1:4)
 !//////////////////
-         write(*,'(3i4, 1p, g13.4, 0p, f10.4,1p, 6g13.4)')
+!         write(*,'(3i4, 1p, g13.4, 0p, f10.4,1p, 6g13.4)')
+!     *   a(i)%code,  a(i)%subcode,  a(i)%charge,
+!     *     pt, y,  eta, a(i)%fm%p(4)-a(i)%mass,  a(i)%fm%p(3),
+!     *     ylab, etalab
+         write(*,'(3i4, 1p, 3g13.4)')
      *   a(i)%code,  a(i)%subcode,  a(i)%charge,
-     *     pt, y,  eta, a(i)%fm%p(4)-a(i)%mass,  a(i)%fm%p(3),
-     *     ylab, etalab
+     *      a(i)%fm%p(4)-a(i)%mass,    a(i)%fm%p(3), wz
+
+         
       enddo
       if(ntp .gt. 0 .or. outzero .eq. 1) then
          write(*, *) 
