@@ -3,7 +3,7 @@
        real*8 TargetZ2        ! <Z^2> of the target
 !       integer TargetNucleonNo  !  target nucleon number at a collision. sampled at each collision
        real*8 TargetZ2_3rd  ! <Z>^(2/3).  Since <Z> is almost same as 7 or 8
-c                    we simpley use this as <Z^2/3>
+!                    we simpley use this as <Z^2/3>
        real*8 TargetZ1_3rd  !  <Z>^(1/3).  same reason
 
 !       integer TargetProtonNo  !  target proton number  //     //
@@ -14,7 +14,7 @@ c                    we simpley use this as <Z^2/3>
      *  TargetZ1_3rd
 !     *, TargetXs, TargetNucleonNo, TargetProtonNo
 !   last 3 moved to modXsecMedia 
-	 save /Zair/
+          save /Zair/
 
 
 
