@@ -19,12 +19,12 @@
      *  PrSTLB,  BrSTSA, BrSTSB, BrTXS,
      *  PrTXL, BrTXL
 
-c    *BrTXL, BrSTLA, BrSTLB, BrTXH, BrSTHA, BrSTHB, PrTXL, PrSTLA, 
-c    *PrSTLB, PrTXH, PrSTH, BrTXS, BrSTSA, BrSTSB
-c     * , MuNTX, MuNdEdx0, 
-c     *MuNdEdxt, MuBrTX, MuBrdEdx0, MuBrdEdxt, MuPrTX, MuPrdEdx0, 
-c     *MuPrdEdxt, MuNTbl, MuBrTbl, MuPrTbl
-c
+!    *BrTXL, BrSTLA, BrSTLB, BrTXH, BrSTHA, BrSTHB, PrTXL, PrSTLA, 
+!    *PrSTLB, PrTXH, PrSTH, BrTXS, BrSTSA, BrSTSB
+!     * , MuNTX, MuNdEdx0, 
+!     *MuNdEdxt, MuBrTX, MuBrdEdx0, MuBrdEdxt, MuPrTX, MuPrdEdx0, 
+!     *MuPrdEdxt, MuNTbl, MuBrTbl, MuPrTbl
+!
 
           
      
