@@ -68,4 +68,4 @@
 !     4)  if it is >=3,  a particle makes a step. id=7
 !        
 #define  DETAILED_TRACKING 0
-#endif  /* Zcondc.h */
+#endif  /* Zcondc%h */
