@@ -1,18 +1,19 @@
-c  #ifndef Zcoord_
-c  #define Zcoord_
+!  #ifndef Zcoord_
+!  #define Zcoord_
 #include "Zunionmap.h"
-c        sys="xyz":  origin is center of the Earth.
-c              x:  directed to longitude 0, latitude 0
-c              y:  directed to longitude 90 deg, latitude 0
-c              z:  center to the North pole
-c  ****************************************************************
-c  *       During the paticle tracking, this system is used.      *
-c  ****************************************************************
-c
+!        sys="xyz":  origin is center of the Earth.
+!              x:  directed to longitude 0, latitude 0
+!              y:  directed to longitude 90 deg, latitude 0
+!              z:  center to the North pole
+!  ****************************************************************
+!  *       During the paticle tracking, this system is used.      *
+!  ****************************************************************
+!
 
 
-c
-      structure /coord/
+!
+      type coord
+        sequence
 #ifdef  UNIONMAP
           union
               map
@@ -36,5 +37,5 @@ c
           endunion
 #endif
           character*4 sys  ! which system. 'xyz', 'llh', 'sph'
-      end structure
-c  #endif /* Zcoord.h */
+      end type coord
+!  #endif /* Zcoord.h */
