@@ -5,7 +5,8 @@
      +  ASDepthList, ASHeightList, Azimuth, BaseTime, Cont, ContFile
      +, CosZenith, CutOffFile, Ddelta, DeadLine, DepthList, DestEventNo
      +, DtGMT, Freec, Generate, HeightList, HeightOfInj, Hidden
-     +, IncMuonPolari, InitRN, IntModel, MCSmodel
+     +, IncMuonPolari, InitRN, IntModel, MCSmodel, MCSdir, MCSparam
+     +, MCSzRange, MCSnumRange, MCSandor, MCSrevert, MCSdebug
      +, Job, KEminObs, LatitOfSite
      +, LongitOfSite, LpmEffect, MinPhotoProdE, ObsPlane, OneDim
      +, PhotoProd, PrimaryFile, SeedFile, SkeletonFile, SourceDec
