@@ -1,8 +1,9 @@
-c         This namelist data may be given only some
-c         special purpose such as to see the scattering effect
-c         by putting  Es = 0.
+!         This namelist data may be given only some
+!         special purpose such as to see the scattering effect
+!         by putting  Es = 0.
 
        namelist  /HParam/
+     +  ALateCor, 
      +  AnihiE, AtEnv, AtmosFile, BackAngLimit, BaseErg, BasePower
      +, BorderHeightH, BorderHeightL, Cekaon, Ceneuc, Cepic0
      +, Charge2heavyG, Code2heavyG, Code2massN, DefofR
@@ -14,7 +15,7 @@ c         by putting  Es = 0.
      +, GeomagFile
      +, HeavyG2charge, HeavyG2code, HeavyG2massN, HeavyG2symbol
      +, HowGeomag, HowIntNuc, HowEfield,  HowPhotoP, ASRforDPM
-     +, InclusiveFile, IncreaseXsec, KEminObs2
+     +, InclusiveFile, IncreaseXsec, K0sSemiLD, KEminObs2
      +, KnockOnRatio, Knockon, Kpicns, Kpilog, LamorDiv, LpmBremEmin
      +, LpmPairEmin, LundPara, MagBrem, MagBremEmin, MagChgDist, MagD
      +, MagE, MagN, MagPair, MagPairEmin, MaxComptonE, MaxPhotoE
